# coding: utf-8

"""
    VeeRoute.LSS Account

    LSS Account Panel  # noqa: E501

    The version of the OpenAPI document: 3.4.161082
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_lss_account
from vrt_lss_account.models.date_statistics import DateStatistics  # noqa: E501
from vrt_lss_account.rest import ApiException

class TestDateStatistics(unittest.TestCase):
    """DateStatistics unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DateStatistics
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_lss_account.models.date_statistics.DateStatistics()  # noqa: E501
        if include_optional :
            return DateStatistics(
                date = 'Mon Oct 05 03:00:00 MSK 2020', 
                services = [
                    vrt_lss_account.models.service_statistics.ServiceStatistics(
                        service = 'Lastmile', 
                        methods = [
                            vrt_lss_account.models.method_statistics.MethodStatistics(
                                method = 'plan', 
                                unique_points_per_day = 1500, 
                                points_per_day = 1500, )
                            ], )
                    ]
            )
        else :
            return DateStatistics(
                date = 'Mon Oct 05 03:00:00 MSK 2020',
                services = [
                    vrt_lss_account.models.service_statistics.ServiceStatistics(
                        service = 'Lastmile', 
                        methods = [
                            vrt_lss_account.models.method_statistics.MethodStatistics(
                                method = 'plan', 
                                unique_points_per_day = 1500, 
                                points_per_day = 1500, )
                            ], )
                    ],
        )

    def testDateStatistics(self):
        """Test DateStatistics"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    VeeRoute.LSS Account

    LSS Account Panel  # noqa: E501

    The version of the OpenAPI document: 3.4.161082
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_lss_account.configuration import Configuration


class InlineResponse400Validations(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'entity_key': 'str',
        'entity_type': 'str',
        'info': 'str'
    }

    attribute_map = {
        'type': 'type',
        'entity_key': 'entity_key',
        'entity_type': 'entity_type',
        'info': 'info'
    }

    def __init__(self, type=None, entity_key=None, entity_type=None, info=None, local_vars_configuration=None):  # noqa: E501
        """InlineResponse400Validations - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._entity_key = None
        self._entity_type = None
        self._info = None
        self.discriminator = None

        self.type = type
        if entity_key is not None:
            self.entity_key = entity_key
        if entity_type is not None:
            self.entity_type = entity_type
        self.info = info

    @property
    def type(self):
        """Gets the type of this InlineResponse400Validations.  # noqa: E501

        Validation type: * `info`  * `warning`  * `error`    # noqa: E501

        :return: The type of this InlineResponse400Validations.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this InlineResponse400Validations.

        Validation type: * `info`  * `warning`  * `error`    # noqa: E501

        :param type: The type of this InlineResponse400Validations.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["info", "warning", "error"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def entity_key(self):
        """Gets the entity_key of this InlineResponse400Validations.  # noqa: E501

        Entity description.  # noqa: E501

        :return: The entity_key of this InlineResponse400Validations.  # noqa: E501
        :rtype: str
        """
        return self._entity_key

    @entity_key.setter
    def entity_key(self, entity_key):
        """Sets the entity_key of this InlineResponse400Validations.

        Entity description.  # noqa: E501

        :param entity_key: The entity_key of this InlineResponse400Validations.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                entity_key is not None and len(entity_key) > 1024):
            raise ValueError("Invalid value for `entity_key`, length must be less than or equal to `1024`")  # noqa: E501

        self._entity_key = entity_key

    @property
    def entity_type(self):
        """Gets the entity_type of this InlineResponse400Validations.  # noqa: E501

        Entity type.  # noqa: E501

        :return: The entity_type of this InlineResponse400Validations.  # noqa: E501
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """Sets the entity_type of this InlineResponse400Validations.

        Entity type.  # noqa: E501

        :param entity_type: The entity_type of this InlineResponse400Validations.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                entity_type is not None and len(entity_type) > 1024):
            raise ValueError("Invalid value for `entity_type`, length must be less than or equal to `1024`")  # noqa: E501

        self._entity_type = entity_type

    @property
    def info(self):
        """Gets the info of this InlineResponse400Validations.  # noqa: E501

        Information about validation.  # noqa: E501

        :return: The info of this InlineResponse400Validations.  # noqa: E501
        :rtype: str
        """
        return self._info

    @info.setter
    def info(self, info):
        """Sets the info of this InlineResponse400Validations.

        Information about validation.  # noqa: E501

        :param info: The info of this InlineResponse400Validations.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and info is None:  # noqa: E501
            raise ValueError("Invalid value for `info`, must not be `None`")  # noqa: E501

        self._info = info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse400Validations):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse400Validations):
            return True

        return self.to_dict() != other.to_dict()
